From 2c8f38189e04d2ffd7ed159b3f2f223b1a462181 Mon Sep 17 00:00:00 2001
From: Guennadi Liakhovetski <g.liakhovetski@gmx.de>
Date: Thu, 12 Apr 2012 15:20:25 +0200
Subject: [PATCH] omap4xxx: simplify conditional expressions

gcc guarantees, that in a conditional expression of the form "A || B" B is
only evaluated, if A is false. Also remove multiple superfluous parenthesis
in those expressions.

Change-Id: I7252d295014dd364f6ca7e65c19ba7bea9496d01
---
 camera/CameraHal.cpp |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/hardware/ti/omap4xxx/camera/CameraHal.cpp b/hardware/ti/omap4xxx/camera/CameraHal.cpp
index c7ba87f..9d892df 100644
--- a/hardware/ti/omap4xxx/camera/CameraHal.cpp
+++ b/hardware/ti/omap4xxx/camera/CameraHal.cpp
@@ -1828,7 +1828,7 @@ status_t CameraHal::startRecording( )
     // only need to check recording hint if preview restart is not already needed
     valstr = mParameters.get(CameraParameters::KEY_RECORDING_HINT);
     if ( !restartPreviewRequired &&
-         (!valstr || (valstr && (strcmp(valstr, CameraParameters::TRUE) != 0))) ) {
+         (!valstr || strcmp(valstr, CameraParameters::TRUE) != 0) ) {
         restartPreviewRequired = setVideoModeParameters(mParameters);
     }
 
@@ -1907,8 +1907,8 @@ bool CameraHal::setVideoModeParameters(const CameraParameters& params)
 
     // Set CAPTURE_MODE to VIDEO_MODE, if not set already and Restart Preview
     valstr = mParameters.get(TICameraParameters::KEY_CAP_MODE);
-    if ( (valstr == NULL) ||
-        ( (valstr != NULL) && (strcmp(valstr, (const char *) TICameraParameters::VIDEO_MODE) != 0) ) )
+    if ( valstr == NULL ||
+	 strcmp(valstr, (const char *) TICameraParameters::VIDEO_MODE) != 0 )
         {
         CAMHAL_LOGDA("Set CAPTURE_MODE to VIDEO_MODE");
         mParameters.set(TICameraParameters::KEY_CAP_MODE, (const char *) TICameraParameters::VIDEO_MODE);
-- 
1.7.2.5

